# global settings file

# test for the platform
PLATFORM := $(shell uname)

# special check for windows because normally we have no uname under windows
ifeq "$(PLATFORM)" ""
PLATFORM = windows
else
ifeq "$(PLATFORM)" "WINNT"
PLATFORM = windows
endif
ifeq "$(PLATFORM)" "CYGWIN_NT-5.0"
PLATFORM = windows
endif
endif

ifeq "$(PLATFORM)" "windows"
# Settings for Windows using Microsoft compiler/linker

OS=WIN
PS=\\
CC=cl
LINK=link
BUILDLIB=lib
ECHO=@echo
MKDIR=mkdir
MV=move
CAT=type
OBJ_EXT=obj
EXE_EXT=.exe
COPY=copy
SHAREDLIB_EXT=dll
SHAREDLIB_OUT=$(OUT_BIN)

OSEP=^<
CSEP=^>

DEL=del
URLPREFIX=file:///

SALLIB=isal.lib
CPPULIB=icppu.lib
CPPUHELPERLIB=icppuhelper.lib
SALHELPERLIB=isalhelper.lib
STLPORTLIB=stlport_vc6.lib

EMPTYSTRING=
PATH_SEPARATOR=;

# use this for release version
# CC_FLAGS=-c -GX
CC_FLAGS=-c -GX -Zi -MT
CC_INCLUDES=-I. -I$(OUT)$(PS)inc$(PS)examples -I$(PRJ)$(PS)include

# define for used compiler necessary for UNO
# -DCPPU_ENV=msci -- windows msvc 4.x - 7.x

CC_DEFINES=-DWIN32 -DCPPU_ENV=msci
CC_OUTPUT_SWITCH=-Fo

LIBRARY_LINK_FLAGS=/NODEFAULTLIB /DLL /DEBUG:notmapped,full /DEBUGTYPE:cv
EXE_LINK_FLAGS=/MAP /OPT:NOREF /SUBSYSTEM:CONSOLE /BASE:0x1100000 /DEBUG:notmapped,full /DEBUGTYPE:cv

# use this for release version
#EXE_LINK_FLAGS=/MAP /OPT:NOREF /SUBSYSTEM:CONSOLE /BASE:0x1100000
#LIBRARY_LINK_FLAGS=/NODEFAULTLIB /DLL
endif	




ifeq "$(PLATFORM)" "SunOS"
# Settings for Solaris using Sun Workshop compiler

PROCTYPE := $(shell uname -p)

ifeq "$(PROCTYPE)" "sparc"
PLATFORM=solsparc
else
PLATFORM=solintel
endif

OS=SOLARIS
PS=/
CC=CC
LINK=CC
LIB=CC
ECHO=@echo
MKDIR=mkdir -p
CAT=cat
OBJ_EXT=o
SHAREDLIB_EXT=so
SHAREDLIB_PRE=lib
SHAREDLIB_OUT=$(OUT_LIB)

OSEP=\<
CSEP=\>

DEL=rm -f
COPY=cp
URLPREFIX=file://

# Include UDK version numbers
include $(PRJ)$(PS)include$(PS)udkversion.mk

SALLIB=-lsal
CPPULIB=-lcppu
CPPUHELPERLIB=-lcppuhelper$(UDK_MAJOR)C52
SALHELPERLIB=-lsalhelper$(UDK_MAJOR)C52
STLPORTLIB=-lstlport_sunpro

EMPTYSTRING=
PATH_SEPARATOR=:

CC_FLAGS=-c -KPIC
CC_INCLUDES=-I. -I$(PS)usr$(PS)include -I$(OUT)$(PS)inc$(PS)examples -I$(PRJ)$(PS)include

# define for used compiler necessary for UNO
# -DCPPU_ENV=sunpro5 -- sunpro cc 5.x solaris sparc/intel

CC_DEFINES=-DUNX -DSOLARIS -DSPARC -DCPPU_ENV=sunpro5
CC_OUTPUT_SWITCH=-o 

LIBRARY_LINK_FLAGS=-w -PIC -temp=$(PS)tmp -R $(PS)usr$(PS)lib -G -lthread -instances=static 
LINK_LIBS=-L$(OUT)$(PS)lib -L$(PRJ)$(PS)lib -L$(PS)usr$(PS)lib -L$(PS)usr$(PS)local$(PS)lib -L$(PS)lib

endif




ifeq "$(PLATFORM)" "Linux"
# Settings for Linux using gcc compiler

OS=LINUX
PLATFORM=linux
PS=/
CC=gcc
LINK=gcc
LIB=gcc
ECHO=@echo
MKDIR=mkdir -p
CAT=cat
OBJ_EXT=o
SHAREDLIB_EXT=so
SHAREDLIB_PRE=lib
SHAREDLIB_OUT=$(OUT_LIB)
GCC_VERSION=$(shell $(CC) --version)
ifeq "$(shell echo $(GCC_VERSION) | cut -c 1)" "3"
COMID=gcc3
CPPU_ENV=gcc3

STDC++LIB=-lsupc++
else
COMID=GCC
CPPU_ENV=gcc2

STDC++LIB=-lstdc++
endif

OSEP=\<
CSEP=\>
    
DEL=rm -f
COPY=cp
URLPREFIX=file://

# Include UDK version numbers
include $(PRJ)$(PS)include$(PS)udkversion.mk

SALLIB=-lsal
CPPULIB=-lcppu
CPPUHELPERLIB=-lcppuhelper$(UDK_MAJOR)$(COMID)
SALHELPERLIB=-lsalhelper$(UDK_MAJOR)$(COMID)
STLPORTLIB=-lstlport_gcc

EMPTYSTRING=
PATH_SEPARATOR=:

# -O is necessary for inlining (see gcc documentation)
CC_FLAGS=-c -O
CC_INCLUDES=-I. -I$(PS)usr$(PS)include -I$(OUT)$(PS)inc$(PS)examples -I$(PRJ)$(PS)include
CC_DEFINES=-DUNX -DGCC -DLINUX -DCPPU_ENV=$(CPPU_ENV)

# define for used compiler necessary for UNO
#-DCPPU_ENV=gcc2 -- gcc 2.91/2.95
#-DCPPU_ENV=gcc3 -- gcc3 3.0

CC_OUTPUT_SWITCH=-o

LIBRARY_LINK_FLAGS=-shared
EXE_LINK_FLAGS=-Wl -export-dynamic
LINK_LIBS=-L$(OUT)$(PS)lib -L$(PRJ)$(PS)$(PLATFORM)$(PS)lib -L$(PS)usr$(PS)lib -L$(PS)usr$(PS)local$(PS)lib -L$(PS)lib

endif
